@@ -198,7 +198,9 @@ void QueueView::setPauseOnHSUnplugged(bool state)
 void QueueView::setupMenubar()
 {
     //setup the view menubar
+#ifdef Q_WS_MAEMO_5
     menuBar()->addAction(tr("FM Transmitter")); //add FM transmitter button to the menubar
+#endif
 }
 
 void QueueView::OnMenubarAction(QAction* action)
@@ -211,6 +213,7 @@ void QueueView::OnMenubarAction(QAction* action)
         //(i.e., requests to execute the control panel FM Transmitter plugin)
         emit showFMTransmitterDialog();
     }
+
 }
 
 void QueueView::show()
@@ -244,6 +247,7 @@ void QueueView::setListViewState()
     }
 }
 
+#ifdef Q_WS_MAEMO_5
 void QueueView::OnPlaybackStateChangeRequest(enum pb_state_e requestedState)
 {
    //request received via libplayback asking for a playback state change
@@ -257,6 +261,7 @@ void QueueView::OnPlaybackStateChangeRequest(enum pb_state_e requestedState)
         }
     }
 }
+#endif
 
 void QueueView::setQueueInitialState(QList<Spotify::Track*> queue, qint32 currQueuePos)
 {
@@ -288,8 +293,10 @@ void QueueView::setQueueInitialState(QList<Spotify::Track*> queue, qint32 currQu
 
     if(m_pCurrTrack)
     {
+#ifdef Q_WS_MAEMO_5
         if(m_pOssoWrapper)
             m_pOssoWrapper->requestPlaybackStateChange(PB_STATE_PLAY); //request to move into playing state
+#endif
         playTrack(m_pCurrTrack); //initiate track playback
         m_PauseResumeBtn.setEnabled(true);
         m_PauseResumeBtn.setChecked(true);
@@ -384,7 +391,12 @@ void QueueView::OnBufferNextTrack()
             error = m_pSession->play(track,true); //initiate buffering of track
             if(error.isError())
             {
+#ifdef Q_WS_MAEMO_5
                 QMaemo5InformationBox::information(this,tr("Error starting track playback: ") + error.toString());
+#else
+                Banner::information(this,tr("Error starting track playback: ") + error.toString());
+#endif
+
             }
         }
     }
@@ -429,7 +441,9 @@ void QueueView::addTracks(QList<Spotify::Track*> trackList)
 
     QIcon trackTypeIcon(iconMap);
 
+#ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //display progress indicator
+#endif
 
     //m_TrackInfo.clear();
     m_pTrackInfoModel->clear();
@@ -453,8 +467,9 @@ void QueueView::addTracks(QList<Spotify::Track*> trackList)
                  m_pTrackInfoModel->appendRow(trackInfo);
              }
      }
-
+#ifdef Q_WS_MAEMO_5
      setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false);
+#endif
 }
 
 void QueueView::OnTrackActivated(QModelIndex index)
@@ -499,11 +514,13 @@ void QueueView::playTrack(Spotify::Track* track)
     Spotify::Error error;
     QString strArtist, strAlbum, strTrack, strAlbumArtist;
 
+#ifdef Q_WS_MAEMO_5
     if(m_playbackStateChangeReq)
     { //ask for state change
         m_playbackStateChangeReq = false;
         m_pOssoWrapper->requestPlaybackStateChange(PB_STATE_PLAY);
     }
+#endif
     m_currTrackScrobbled = false;
     m_pSession->resetPlaybackMembers();
     loadTrackData(track);
@@ -511,12 +528,22 @@ void QueueView::playTrack(Spotify::Track* track)
     m_userInitiatedPause = false;
     m_pProgressSlider->setPos1(0);
     m_pProgressSlider->setPos2(0);
+#ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //display progress indicator
     QMaemo5InformationBox::information(this,tr("Buffering"));
+#else
+    Banner::information(this,tr("Buffering"));
+#endif
+
     error = m_pSession->play(track); //request to start playback of track
     if(error.isError())
     { //error occured
+#ifdef Q_WS_MAEMO_5
         QMaemo5InformationBox::information(this,tr("Error starting track playback: ")+error.toString());
+#else
+        Banner::information(this,tr("Error starting track playback: ")+error.toString());
+#endif
+
     }
     else
     { //set state of pause / resume button
@@ -533,7 +560,9 @@ void QueueView::playTrack(Spotify::Track* track)
         }
         emit updateNowPlaying(strTrack,strArtist,strAlbum,strAlbumArtist); //send update now playing request to Last.fm
     }
+#ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide progress indicator
+#endif
 }
 
 void QueueView::OnTrackBufferedAmountUpdated(qint32 bufferedAmount)
@@ -606,11 +635,13 @@ void QueueView::OnPauseResumeToggle()
 
     if(m_pCurrTrack) //some track has been activated
     {
+#ifdef Q_WS_MAEMO_5
         if(m_playbackStateChangeReq)
         { //ask for state change
             m_playbackStateChangeReq = false;
             m_pOssoWrapper->requestPlaybackStateChange(PB_STATE_PLAY); //notify via libplayback that we are entering playing state
         }
+#endif
         if(!m_PauseResumeBtn.isChecked()) //entering paused state
         {
             qDebug() << "User paused playback..";
@@ -817,7 +848,11 @@ void QueueView::OnTrackPlaybackFinished()
                 error = m_pSession->play(m_pCurrTrack); //initiate track playback
                 if(error.isError())
                 {
+#ifdef Q_WS_MAEMO_5
                     QMaemo5InformationBox::information(this,tr("Error starting track playback: ") + error.toString());
+#else
+                    Banner::information(this,tr("Error starting track playback: ") + error.toString());
+#endif
                 }
             }
             else
@@ -836,7 +871,11 @@ void QueueView::OnTrackPlaybackFinished()
                         error = m_pSession->play(m_pCurrTrack); //initiate track playback
                         if(error.isError())
                         {
+#ifdef Q_WS_MAEMO_5
                             QMaemo5InformationBox::information(this,tr("Error starting track playback: ") + error.toString());
+#else
+                            Banner::information(this,tr("Error starting track playback: ") + error.toString());
+#endif
                         }
                     }
                 }
@@ -947,8 +986,13 @@ void QueueView::OnPlayAlbumAction()
             if(m_pSession->browse(track->getAlbum(),&m_CallerID)) //request to load album tracks (browse album)
             {
                 m_pTrackInfoView->setDisabled(true);
+#ifdef Q_WS_MAEMO_5
                 QMaemo5InformationBox::information(this,tr("Loading album tracks"));
                 setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true);
+#else
+                Banner::information(this,tr("Loading album tracks"));
+#endif
+
             }
         }
     }
@@ -968,13 +1012,22 @@ void QueueView::OnAlbumBrowseReady(Spotify::AlbumBrowser* browser, qint32 caller
             if(error.isError())
             {
                 //error occured (album browse request failed)
+#ifdef Q_WS_MAEMO_5
                 QMaemo5InformationBox::information(this,tr("Fetching of album tracks failed: ") + error.toString());
+#else
+                Banner::information(this,tr("Fetching of album tracks failed: ") + error.toString());
+#endif
+
             }
             else
             {
                 if(!browser->load())
                 {
+#ifdef Q_WS_MAEMO_5
                     QMaemo5InformationBox::information(this,tr("Failed to load tracks!"));
+#else
+                    Banner::information(this,tr("Failed to load tracks!"));
+#endif
                 }
                 browser->sortByDiscIndex(); //sort tracks in album order
                 emit playQueueSet(browser->getTracks(false),0); //only add available (playable) album tracks to the playqueue
@@ -982,7 +1035,9 @@ void QueueView::OnAlbumBrowseReady(Spotify::AlbumBrowser* browser, qint32 caller
             }
         }
     }
+#ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false);
+#endif
     m_pTrackInfoView->setDisabled(false);
 }
 
@@ -1155,6 +1210,15 @@ void QueueView::OnPlaybackTokenLost()
         pauseResumePlayback();
 }
 
+void QueueView::setHideCoverart(bool hide)
+{
+    //Set the album coverart display state (based upon hide parameter)
+    if(hide)
+        m_AlbumCover.setVisible(false);
+    else
+        m_AlbumCover.setVisible(true);
+}
+
 /*void QueueView::OnProgressSliderClicked(int pos)
 {
     //progress slider has been clicked (pos=clicked position)
