@@ -22,7 +22,11 @@
 #include <QTextStream>
 #include <QKeyEvent>
 #include <QtGui/QPixmap>
-#include <QMaemo5InformationBox>
+#ifdef Q_WS_MAEMO_5
+    #include <QMaemo5InformationBox>
+#else
+    #include "Banner.h"
+#endif
 #include <QAction>
 #include <qspotify_src/spotifysession.h>
 #include <qspotify_src/imagecontainer.h>
@@ -39,9 +43,14 @@
 #define SLIDER_HEIGHT 40 //height of the custom progress slider widget
 #define SLIDER_WIDTH_PORTRAIT 440 //width of the custom progress slider widget (portrait mode)
 
-
+#ifdef Q_WS_MAEMO_5
 #define QUEUEVIEW_COVERART_WIDTH_LANDSCAPE    355
 #define QUEUEVIEW_COVERART_HEIGHT_LANDSCAPE   355
+#else
+#define QUEUEVIEW_COVERART_WIDTH_LANDSCAPE    300
+#define QUEUEVIEW_COVERART_HEIGHT_LANDSCAPE   300
+#endif
+
 
 #define QUEUEVIEW_ID 1
 
@@ -60,6 +69,8 @@ public:
 
     virtual void show(); //overriden show method
 
+    void setHideCoverart(bool hide); //set the album coverart display state (based upon hide parameter)
+
 
 protected:
 
@@ -187,7 +198,9 @@ private slots:
     void OnPrevTrackBtn();
     void OnBufferNextTrack();
     void OnMenubarAction(QAction* action);
+#ifdef Q_WS_MAEMO_5
     void OnPlaybackStateChangeRequest(enum pb_state_e requestedState);
+#endif
     void OnViewAlbumAction();
     void OnPlayAlbumAction();
     void OnViewArtistAction();
