@@ -81,7 +81,9 @@ void LoginDialog::OnLogin()
     else
     {
         m_LoginBtn.setDisabled(true);
+#ifdef Q_WS_MAEMO_5
         setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //display progress indicator
+#endif
     }
 }
 
@@ -89,7 +91,9 @@ void LoginDialog::OnLogin()
 void LoginDialog::resetState()
 {
 	//reset state after e.g., unsuccessful login
+#ifdef Q_WS_MAEMO_5
 	setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide progress indicator
+#endif
 	m_LoginBtn.setDisabled(false);
         //m_UserIDInput.setText("");
 	m_UserIDInput.setCursorPosition(0);
