@@ -10,20 +10,11 @@
 #include <QtGui/QMessageBox>
 #include <QtGui/QCheckBox>
 #include <QtGui/QComboBox>
-#include <QStringListModel>
-#include <QMaemo5ListPickSelector>
-#include <QMaemo5ValueButton>
 #include <QDebug>
 #include <QSettings>
 #include <qspotify_src/spotifysession.h>
 #include "global_defs.h"
 
-//misc. defines
-
-#define IDX_BITRATE_96k 0
-#define IDX_BITRATE_160k 1
-#define IDX_BITRATE_320k 2
-
 
 class LoginDialog : public QDialog
 {
@@ -47,12 +38,6 @@ private:
     QLabel m_PasswordText;
     QLineEdit m_PasswordInput;
 
-    QCheckBox m_SaveCredentials;
-
-    QStringList m_bitrateList; //list of bitrate alternatives
-
-    QMaemo5ValueButton m_PreferredBitrate;
-
     QPushButton m_LoginBtn;
 
     QSettings* m_pAppSettings; //pointer to app settings instance
@@ -62,8 +47,6 @@ private:
 private slots:
 
     void OnLogin();
-    void OnLoggedIn(Spotify::Error);
-    void bitrateSelectionChanged(const QString& selection);
     void OnOrientationChanged(); //device orientation changed (e.g, screen rotate)
 
 };
