@@ -21,6 +21,8 @@ MainWindow::MainWindow(QWidget *parent)
 
     m_update = false;
 
+    m_reConnectReq = false;
+
     m_pSpectrum = new SpectrumAnalyzer(this,55,40);
     m_pSpectrum->setColor(QColor(255,255,255)); //set spectrum color to white
 
@@ -28,18 +30,22 @@ MainWindow::MainWindow(QWidget *parent)
 
     m_pOssoWrapper = new OssoWrapper("QSpot", APP_VERSION, this); //create wrapper instance for libosso
 
+#ifdef Q_WS_MAEMO_5
     if(m_pOssoWrapper)
     { //register / declare new playback object with OSSO libplayback (whitelisting support / support for playing in silent profile)
         m_pOssoWrapper->initOssoPlayback("QSpot");
         m_pOssoWrapper->requestPlaybackStateChange(PB_STATE_STOP); //request to enter initial stopped state
     }
+#endif
 
     m_pDBusWrapper = new DBusWrapper(this); //allocate D-bus interface wrapper
     if(m_pDBusWrapper)
     {
-        m_pDBusWrapper->enableHWZoomKeys(); //enable / grab control of the HW zoom controls (for volume control when phone is locked)
         connect(m_pDBusWrapper,SIGNAL(onDisplayStateChange(bool)),SLOT(OnDisplayStateChanged(bool)));
+#ifdef Q_WS_MAEMO_5
+        m_pDBusWrapper->enableHWZoomKeys(); //enable / grab control of the HW zoom controls (for volume control when phone is locked)
         connect(m_pDBusWrapper,SIGNAL(onZoomKeyPressed(quint32)),SLOT(OnHWZoomKeyPressed(quint32)));
+#endif
     }
 
     m_pLastFMScrobbler = new LastFMScrobbler(this); //allocate Last.fm scrobbler instance
@@ -51,6 +57,10 @@ MainWindow::MainWindow(QWidget *parent)
     connect(m_pLastFMScrobbler,SIGNAL(updateNowPlayingStatus(bool,const QString&)),SLOT(OnScrobblingStatus(bool, const QString&)));
     connect(m_pLastFMScrobbler,SIGNAL(scrobbleTracksStatus(bool,const QString&)),SLOT(OnScrobblingStatus(bool, const QString&)));
 
+    m_pConnMan = new ConnectionManager(this); //allocate connection manager instance
+    connect(m_pConnMan,SIGNAL(reconnectRequired()),SLOT(OnSpotifyReconnectRequired()));
+
+
     m_pTimeoutTimer  = new QTimer(this); //timeout timer instance
     connect(m_pTimeoutTimer,SIGNAL(timeout()),SLOT(OnPlaylistLoadingTimeout()));
 
@@ -60,7 +70,9 @@ MainWindow::MainWindow(QWidget *parent)
 
     //set up the the main window menu
     menuBar()->addAction(tr("Settings"));
+#ifdef Q_WS_MAEMO_5
     menuBar()->addAction(tr("FM Transmitter"));
+#endif
     menuBar()->addAction(tr("About"));
 
     //setup the app About dialog box
@@ -102,6 +114,7 @@ MainWindow::MainWindow(QWidget *parent)
     connect(m_pLoginDlg,SIGNAL(rejected()),SLOT(OnLoginDialogRejected()));
     connect(m_pSettingsDlg,SIGNAL(settingsSaved()),SLOT(OnSettingsSaved()));
     connect(m_pSession,SIGNAL(loggedIn(Spotify::Error)),SLOT(OnLoggedIn(Spotify::Error)));
+    connect(m_pSession,SIGNAL(loggedOut()),SLOT(OnLoggedOut()));
     connect(m_pSession,SIGNAL(playlistContainersReady(QList<Spotify::Playlist*>)),this,SLOT(OnPlaylistContainersReady(QList<Spotify::Playlist*>)));
     connect(m_pSession,SIGNAL(playing(bool)),SLOT(OnPlayingState(bool)));
     connect(m_pSession,SIGNAL(searchComplete(Spotify::Search*)),SLOT(OnSearchComplete(Spotify::Search*)));
@@ -187,7 +200,11 @@ void MainWindow::handleSpotifyLogin()
 
         m_pSession->init(selectedBitrate); //init new session prior to login
 
+#ifdef Q_WS_MAEMO_5
         QMaemo5InformationBox::information(this,tr("Logging in to Spotify"));
+#else
+        Banner::information(this,tr("Logging in to Spotify"));
+#endif
         Spotify::Error err = m_pSession->login(m_pAppSettings->value("QSpot/UserID").toString(),m_pAppSettings->value("QSpot/Password").toString());
         if(err.isError())
         {
@@ -197,7 +214,9 @@ void MainWindow::handleSpotifyLogin()
         }
         else
         {
+#ifdef Q_WS_MAEMO_5
             setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //display progress indicator
+#endif
         }
     }
     else
@@ -239,20 +258,24 @@ void MainWindow::initAboutDialog()
 
 MainWindow::~MainWindow()
 {
+#ifdef Q_WS_MAEMO_5
     if(m_pDBusWrapper)
     {
         m_pDBusWrapper->disableHWZoomKeys(); //release HW keypad (zoomkeys)
     }
+#endif
 }
 
 void MainWindow::OnDisplayFMTransmitterDialog()
 {
     //request to display the standard FMTransmitter configuration dialog (control panel plugin);
 
+#ifdef Q_WS_MAEMO_5
     if(m_pOssoWrapper)
     {
         m_pOssoWrapper->executePlugin("libcpfmtx.so");
     }
+#endif
 }
 
 void MainWindow::OnSettingsSaved()
@@ -300,6 +323,16 @@ void MainWindow::OnSettingsSaved()
         m_pLastFMScrobbler->setCache(true); //enable caching of scrobbles
         m_pLastFMScrobbler->authenticateSession(m_pAppSettings->value("QSpot/lastfmUid","").toString(),m_pAppSettings->value("QSpot/lastfmPwd","").toString());
     }
+
+    //hide coverart state
+    if(m_pAppSettings->value("QSpot/HideCoverart",HIDE_COVERART_DEFAULT).toInt())
+    {
+        m_pQueueView->setHideCoverart(true);
+    }
+    else
+    {
+         m_pQueueView->setHideCoverart(false);
+    }
 }
 
 void MainWindow::OnShowLogin()
@@ -459,7 +492,9 @@ void MainWindow::OnLoggedIn(Spotify::Error error)
 
     if(error.isError())
     {
+#ifdef Q_WS_MAEMO_5
         setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide main window progress indicator
+#endif
         strLoginMsg = tr("Error:") + error.toString(); //write error string
         msgBox.setText(strLoginMsg);
         msgBox.exec();
@@ -467,14 +502,29 @@ void MainWindow::OnLoggedIn(Spotify::Error error)
         emit showLogin(); //display login dialog in case auto-login is enabled and has failed
     }
     else
-    { //successful login to Spotify service, request user playlist / track data
-    	m_pLoginDlg->setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide progress indicator
-    	setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //display main window progress indicator
-    	m_pLoginDlg->hide();
-        m_SearchInput.setFocus(); //set default focus to search field
-        m_pTimeoutTimer->start(m_pAppSettings->value("QSpot/playlistLoadingTO",PLAYLIST_LOADING_TO_DEFAULT).toInt()*1000); //set timeout value (in msecs)
-    	m_pSession->getPlaylistContainer();
-    	QMaemo5InformationBox::information(this,tr("Loading playlists")); //display loading notification
+    { //successful login to Spotify service, request user playlist / track data (in case initial login request)
+        if(!m_reConnectReq) // do not reload playlist metadata on re-connect request
+        {
+    #ifdef Q_WS_MAEMO_5
+            m_pLoginDlg->setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide progress indicator
+            setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //display main window progress indicator
+    #endif
+            m_pLoginDlg->hide();
+            m_SearchInput.setFocus(); //set default focus to search field
+            m_pTimeoutTimer->start(m_pAppSettings->value("QSpot/playlistLoadingTO",PLAYLIST_LOADING_TO_DEFAULT).toInt()*1000); //set timeout value (in msecs)
+           qDebug() << "Got here..";
+            m_pSession->getPlaylistContainer();
+    #ifdef Q_WS_MAEMO_5
+            QMaemo5InformationBox::information(this,tr("Loading playlists")); //display loading notification
+    #else
+            Banner::information(this,tr("Loading playlists")); //display loading notification
+    #endif
+        }
+        else
+        {
+            m_reConnectReq = false;
+            m_pSession->pauseResumeBuffering(); //continue buffering in case it has been in progress before reconnect
+        }
     }
 }
 
@@ -490,10 +540,13 @@ void MainWindow::OnPlaylistLoadingTimeout()
     {
         m_pSession->stopPlaylistLoading(); //interrupt playlist loading
     }
-
+#ifdef Q_WS_MAEMO_5
     QMaemo5InformationBox::information(this,tr("Timeout occured while loading playlists!")); //display timeout notification
-
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //disable progress indicator
+#else
+    Banner::information(this,tr("Timeout occured while loading playlists!")); //display timeout notification
+#endif
+
 
     setupInitialState();
 }
@@ -528,7 +581,9 @@ void MainWindow::OnPlaylistContainersReady(QList<Spotify::Playlist*> playlists)
 
    setupInitialState();
 
+#ifdef Q_WS_MAEMO_5
    setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false);
+#endif
 }
 
 void MainWindow::setupInitialState()
@@ -560,6 +615,16 @@ void MainWindow::setupInitialState()
         m_pLastFMScrobbler->authenticateSession(m_pAppSettings->value("QSpot/lastfmUid","").toString(),m_pAppSettings->value("QSpot/lastfmPwd","").toString());
     }
 
+    //hide coverart state
+    if(m_pAppSettings->value("QSpot/HideCoverart",HIDE_COVERART_DEFAULT).toInt())
+    {
+        m_pQueueView->setHideCoverart(true);
+    }
+    else
+    {
+         m_pQueueView->setHideCoverart(false);
+    }
+
 }
 
 void MainWindow::setDisplayOrientation(qint32 orientation)
@@ -607,7 +672,7 @@ void MainWindow::OnPlaylistActivated(QModelIndex index)
 
         int pos = index.data(Qt::UserRole).toInt();
 
-	Spotify::Playlist* pPlaylist = m_Playlists.at(pos);
+        Spotify::Playlist* pPlaylist = m_Playlists.at(pos);
 
         if(m_pTrackView)
         {
@@ -659,14 +724,21 @@ void MainWindow::OnSearch()
 
         if(m_SearchInput.text().trimmed()!="")
         {
+#ifdef Q_WS_MAEMO_5
             QMaemo5InformationBox::information(this,tr("Searching"));
             setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //display progress indicator
-
+#else
+            Banner::information(this,tr("Searching"));
+#endif
             error = m_pSession->search(m_SearchInput.text(),0,maxTracks,0,maxAlbums,0,maxArtists,NULL);
             if(error.isError())
             { //some error occured
+#ifdef Q_WS_MAEMO_5
                 QMaemo5InformationBox::information(this,tr("Error: ") + error.toString());
                 setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide progress indicator
+#else
+                Banner::information(this,tr("Error: ") + error.toString());
+#endif
             }
         }
     }}
@@ -680,7 +752,11 @@ void MainWindow::OnSearchComplete(Spotify::Search* search)
         Spotify::Error error = sp_search_error(search->getSearch()); //TODO: move into Search class
         if(error.isError())
         { //some error has occured
+#ifdef Q_WS_MAEMO_5
             QMaemo5InformationBox::information(this,tr("Error: ") + error.toString());
+#else
+            Banner::information(this,tr("Error: ") + error.toString());
+#endif
         }
         else
         {
@@ -699,7 +775,11 @@ void MainWindow::OnSearchComplete(Spotify::Search* search)
             }
             else
             {
+#ifdef Q_WS_MAEMO_5
                 QMaemo5InformationBox::information(this,tr("No tracks found!"));
+#else
+                Banner::information(this,tr("No tracks found!"));
+#endif
             }
         }
     }
@@ -707,13 +787,20 @@ void MainWindow::OnSearchComplete(Spotify::Search* search)
     m_SearchInput.setText(""); //clear search field
     m_SearchInput.setCursorPosition(0);
     m_SearchInput.setFocus(); //set focus to search field
+#ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide progress indicator
+#endif
 }
 
 void MainWindow::OnPlaybackTokenLost()
 {
     //playback token has been lost (e.g., same account has logged in from somewhere else); noitify user
+#ifdef Q_WS_MAEMO_5
      QMaemo5InformationBox::information(this,tr("Playback paused due to the same account being used somewhere else!"));
+#else
+    Banner::information(this,tr("Playback paused due to the same account being used somewhere else!"));
+#endif
+
 }
 
 void MainWindow::OnScrobblingStatus(bool status, const QString& error)
@@ -723,7 +810,12 @@ void MainWindow::OnScrobblingStatus(bool status, const QString& error)
     if(!status)
     {
         //error occured
+#ifdef Q_WS_MAEMO_5
         QMaemo5InformationBox::information(this,tr("Last.fm error: ") + error);
+#else
+         Banner::information(this,tr("Last.fm error: ") + error);
+#endif
+
     }
 }
 
@@ -778,10 +870,13 @@ void MainWindow::OnDisplayStateChanged(bool state)
         m_update = false; //no UI updates
         //disable spectrum analyzer etc.
         m_pSpectrum->Stop();
+#ifdef Q_WS_MAEMO_5
         m_currSysVolume = m_pDBusWrapper->getVolume(); //store the current system volume
+#endif
     }
 }
 
+#ifdef Q_WS_MAEMO_5
 void MainWindow::OnHWZoomKeyPressed(quint32 keycode)
 {
     //notification that HW zoom key has been pressed
@@ -802,3 +897,33 @@ void MainWindow::OnHWZoomKeyPressed(quint32 keycode)
             m_pDBusWrapper->setVolume(m_currSysVolume--); //set new system volume value
     }
 }
+#endif
+
+void MainWindow::OnLoggedOut()
+{
+    //logged out notification for current user
+    Spotify::Error err;
+
+    if(m_reConnectReq)
+    {
+        qDebug() << "Logged out, reconnecting to Spotify..";
+        err = m_pSession->reconnect(); //try to re-connect to Spotify using current session credentials
+        if(err.isError())
+        {//some error occured
+#ifdef Q_WS_MAEMO_5
+            QMaemo5InformationBox::information(this,tr("Failed to re-authenticate with Spotify"));
+#else
+            Banner::information(this,tr("Failed to re-authenticate with Spotify"));
+#endif
+        }
+    }
+}
+
+void MainWindow::OnSpotifyReconnectRequired()
+{
+    //notification that current connection state has changed; reconnection to Spotify backend is required.
+
+    qDebug() << "Reconnect req received..";
+    m_reConnectReq = true;
+    m_pSession->logout(); //logout the current user, before initiating new login
+}
