@@ -51,10 +51,10 @@ PlaybackThread::~PlaybackThread()
 {
     //destructor; do cleanup etc.
     int err=0;
-    m_audio_mutex.lock(); //lock mutex
+    m_audio_mutex.lock();
     pa_simple_flush(m_pAudioStream,&err); //flush playback buffer
     pa_simple_free(m_pAudioStream); //close and free pulseaudio connection
-    m_audio_mutex.unlock(); //release lock
+    m_audio_mutex.unlock();
 }
 
 void PlaybackThread::stop()
@@ -159,6 +159,13 @@ QMutex* PlaybackThread::getMutex()
     return &m_audio_mutex;
 }
 
+void PlaybackThread::flushPAbuffer()
+{
+    //Flush the internal pulseadio buffer
+    int err=0;
+    pa_simple_flush(m_pAudioStream,&err); //flush playback buffer
+}
+
 void PlaybackThread::FIFOAppend(const QByteArray& buffer)
 {
     m_FIFO.append(buffer);
