@@ -1,26 +1,34 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.0" language="nl_NL">
+<context>
+    <name>AboutDialog</name>
+    <message>
+        <location filename="../src/AboutDialog.cpp" line="12"/>
+        <source>Done</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>AlbumView</name>
     <message>
-        <location filename="AlbumView.cpp" line="10"/>
+        <location filename="../src/AlbumView.cpp" line="10"/>
         <source>Browse Album</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="AlbumView.cpp" line="12"/>
-        <location filename="AlbumView.cpp" line="53"/>
+        <location filename="../src/AlbumView.cpp" line="12"/>
+        <location filename="../src/AlbumView.cpp" line="53"/>
         <source>Album Review</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="AlbumView.cpp" line="101"/>
+        <location filename="../src/AlbumView.cpp" line="101"/>
         <source>Fetching of album details failed!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="AlbumView.cpp" line="134"/>
+        <location filename="../src/AlbumView.cpp" line="134"/>
         <source>Fetching of album details failed: </source>
         <translation type="unfinished"></translation>
     </message>
@@ -28,32 +36,32 @@
 <context>
     <name>ArtistView</name>
     <message>
-        <location filename="artistview.cpp" line="12"/>
+        <location filename="../src/artistview.cpp" line="12"/>
         <source>Browse Artist</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="artistview.cpp" line="14"/>
+        <location filename="../src/artistview.cpp" line="14"/>
         <source>Artist Biography</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="artistview.cpp" line="44"/>
+        <location filename="../src/artistview.cpp" line="44"/>
         <source>Biography</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="artistview.cpp" line="81"/>
+        <location filename="../src/artistview.cpp" line="81"/>
         <source>Fetching of artist details failed!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="artistview.cpp" line="86"/>
+        <location filename="../src/artistview.cpp" line="86"/>
         <source>Loading </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="artistview.cpp" line="106"/>
+        <location filename="../src/artistview.cpp" line="106"/>
         <source>Fetching of artist details failed: </source>
         <translation type="unfinished"></translation>
     </message>
@@ -61,53 +69,53 @@
 <context>
     <name>LoginDialog</name>
     <message>
-        <location filename="logindialog.cpp" line="21"/>
+        <location filename="../src/logindialog.cpp" line="21"/>
         <source>QSpot - Login</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="logindialog.cpp" line="24"/>
+        <location filename="../src/logindialog.cpp" line="24"/>
         <source>UserID:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="logindialog.cpp" line="26"/>
+        <location filename="../src/logindialog.cpp" line="26"/>
         <source>Password:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="logindialog.cpp" line="29"/>
-        <location filename="logindialog.cpp" line="176"/>
+        <location filename="../src/logindialog.cpp" line="29"/>
+        <location filename="../src/logindialog.cpp" line="180"/>
         <source>Remember UserID and password</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="logindialog.cpp" line="35"/>
+        <location filename="../src/logindialog.cpp" line="35"/>
         <source>Low bitrate (96kbps)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="logindialog.cpp" line="35"/>
+        <location filename="../src/logindialog.cpp" line="35"/>
         <source>Standard bitrate (160kbps)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="logindialog.cpp" line="36"/>
+        <location filename="../src/logindialog.cpp" line="36"/>
         <source>High bitrate (320kbps)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="logindialog.cpp" line="44"/>
+        <location filename="../src/logindialog.cpp" line="44"/>
         <source>Preferred bitrate</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="logindialog.cpp" line="48"/>
+        <location filename="../src/logindialog.cpp" line="48"/>
         <source>Login</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="logindialog.cpp" line="182"/>
+        <location filename="../src/logindialog.cpp" line="186"/>
         <source>Remember UserID &amp;&amp; Pwd</source>
         <translation type="unfinished"></translation>
     </message>
@@ -115,90 +123,90 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="MainWindow.cpp" line="14"/>
+        <location filename="../src/MainWindow.cpp" line="18"/>
         <source>QSpot - Playlists</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindow.cpp" line="60"/>
-        <location filename="MainWindow.cpp" line="551"/>
+        <location filename="../src/MainWindow.cpp" line="62"/>
+        <location filename="../src/MainWindow.cpp" line="570"/>
         <source>Settings</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindow.cpp" line="61"/>
-        <location filename="MainWindow.cpp" line="557"/>
+        <location filename="../src/MainWindow.cpp" line="63"/>
+        <location filename="../src/MainWindow.cpp" line="576"/>
         <source>FM Transmitter</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindow.cpp" line="62"/>
-        <location filename="MainWindow.cpp" line="561"/>
+        <location filename="../src/MainWindow.cpp" line="64"/>
+        <location filename="../src/MainWindow.cpp" line="580"/>
         <source>About</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindow.cpp" line="172"/>
+        <location filename="../src/MainWindow.cpp" line="179"/>
         <source>About QSpot</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindow.cpp" line="173"/>
+        <location filename="../src/MainWindow.cpp" line="181"/>
         <source>QSpot version </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindow.cpp" line="173"/>
+        <location filename="../src/MainWindow.cpp" line="181"/>
         <source>An open-source Qt-based Spotify client for the N900/Maemo5 (based on libopenspotify).
 
 (C) 2011 Andreas Enbacka and The QSpot Team.
 
-Special thanks to Markus (markusm@tmo) for assistance with the graphical design and layout.</source>
+Special thanks to Markus (markusm@tmo) for assistance with the graphical design and layout, and to Tomi (rantom@tmo) for the Finnish translations.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindow.cpp" line="387"/>
+        <location filename="../src/MainWindow.cpp" line="406"/>
         <source>Error:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindow.cpp" line="400"/>
+        <location filename="../src/MainWindow.cpp" line="419"/>
         <source>Loading playlists</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindow.cpp" line="417"/>
+        <location filename="../src/MainWindow.cpp" line="436"/>
         <source>Timeout occured while loading playlists!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindow.cpp" line="445"/>
+        <location filename="../src/MainWindow.cpp" line="464"/>
         <source>tracks</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindow.cpp" line="583"/>
+        <location filename="../src/MainWindow.cpp" line="602"/>
         <source>Searching</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindow.cpp" line="589"/>
-        <location filename="MainWindow.cpp" line="604"/>
+        <location filename="../src/MainWindow.cpp" line="608"/>
+        <location filename="../src/MainWindow.cpp" line="623"/>
         <source>Error: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindow.cpp" line="623"/>
+        <location filename="../src/MainWindow.cpp" line="642"/>
         <source>No tracks found!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindow.cpp" line="637"/>
+        <location filename="../src/MainWindow.cpp" line="656"/>
         <source>Playback paused due to the same account being used somewhere else!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindow.cpp" line="647"/>
+        <location filename="../src/MainWindow.cpp" line="666"/>
         <source>Last.fm error: </source>
         <translation type="unfinished"></translation>
     </message>
@@ -206,67 +214,67 @@ Special thanks to Markus (markusm@tmo) for assistance with the graphical design
 <context>
     <name>QueueView</name>
     <message>
-        <location filename="QueueView.cpp" line="15"/>
-        <location filename="QueueView.cpp" line="859"/>
-        <location filename="QueueView.cpp" line="868"/>
-        <location filename="QueueView.cpp" line="1012"/>
+        <location filename="../src/QueueView.cpp" line="15"/>
+        <location filename="../src/QueueView.cpp" line="859"/>
+        <location filename="../src/QueueView.cpp" line="868"/>
+        <location filename="../src/QueueView.cpp" line="1012"/>
         <source>Now Playing</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="QueueView.cpp" line="179"/>
+        <location filename="../src/QueueView.cpp" line="179"/>
         <source>Play Album</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="QueueView.cpp" line="182"/>
+        <location filename="../src/QueueView.cpp" line="182"/>
         <source>Browse Album</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="QueueView.cpp" line="185"/>
+        <location filename="../src/QueueView.cpp" line="185"/>
         <source>Browse Artist</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="QueueView.cpp" line="199"/>
-        <location filename="QueueView.cpp" line="206"/>
+        <location filename="../src/QueueView.cpp" line="199"/>
+        <location filename="../src/QueueView.cpp" line="206"/>
         <source>FM Transmitter</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="QueueView.cpp" line="386"/>
-        <location filename="QueueView.cpp" line="518"/>
-        <location filename="QueueView.cpp" line="803"/>
-        <location filename="QueueView.cpp" line="822"/>
+        <location filename="../src/QueueView.cpp" line="386"/>
+        <location filename="../src/QueueView.cpp" line="518"/>
+        <location filename="../src/QueueView.cpp" line="803"/>
+        <location filename="../src/QueueView.cpp" line="822"/>
         <source>Error starting track playback: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="QueueView.cpp" line="514"/>
+        <location filename="../src/QueueView.cpp" line="514"/>
         <source>Buffering</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="QueueView.cpp" line="868"/>
-        <location filename="QueueView.cpp" line="872"/>
-        <location filename="QueueView.cpp" line="1012"/>
-        <location filename="QueueView.cpp" line="1045"/>
+        <location filename="../src/QueueView.cpp" line="868"/>
+        <location filename="../src/QueueView.cpp" line="872"/>
+        <location filename="../src/QueueView.cpp" line="1012"/>
+        <location filename="../src/QueueView.cpp" line="1045"/>
         <source>Shuffle</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="QueueView.cpp" line="933"/>
+        <location filename="../src/QueueView.cpp" line="933"/>
         <source>Loading album tracks</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="QueueView.cpp" line="954"/>
+        <location filename="../src/QueueView.cpp" line="954"/>
         <source>Fetching of album tracks failed: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="QueueView.cpp" line="960"/>
+        <location filename="../src/QueueView.cpp" line="960"/>
         <source>Failed to load tracks!</source>
         <translation type="unfinished"></translation>
     </message>
@@ -274,186 +282,197 @@ Special thanks to Markus (markusm@tmo) for assistance with the graphical design
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="SettingsDialog.cpp" line="46"/>
+        <location filename="../src/SettingsDialog.cpp" line="62"/>
         <source>Landscape</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="SettingsDialog.cpp" line="46"/>
+        <location filename="../src/SettingsDialog.cpp" line="62"/>
         <source>Portrait</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="SettingsDialog.cpp" line="46"/>
+        <location filename="../src/SettingsDialog.cpp" line="62"/>
         <source>Automatic</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="SettingsDialog.cpp" line="101"/>
-        <location filename="SettingsDialog.cpp" line="124"/>
+        <location filename="../src/SettingsDialog.cpp" line="118"/>
+        <location filename="../src/SettingsDialog.cpp" line="142"/>
         <source>QSpot - Settings</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="SettingsDialog.cpp" line="102"/>
+        <location filename="../src/SettingsDialog.cpp" line="119"/>
         <source>Max. tracks returned</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="SettingsDialog.cpp" line="103"/>
+        <location filename="../src/SettingsDialog.cpp" line="120"/>
         <source>Max. albums returned</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="SettingsDialog.cpp" line="104"/>
+        <location filename="../src/SettingsDialog.cpp" line="121"/>
         <source>Max. artists returned</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="SettingsDialog.cpp" line="105"/>
-        <location filename="SettingsDialog.cpp" line="128"/>
+        <location filename="../src/SettingsDialog.cpp" line="122"/>
+        <location filename="../src/SettingsDialog.cpp" line="146"/>
         <source>Search settings</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="SettingsDialog.cpp" line="106"/>
-        <location filename="SettingsDialog.cpp" line="129"/>
+        <location filename="../src/SettingsDialog.cpp" line="123"/>
+        <location filename="../src/SettingsDialog.cpp" line="147"/>
         <source>Buffering settings</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="SettingsDialog.cpp" line="107"/>
+        <location filename="../src/SettingsDialog.cpp" line="124"/>
         <source>Min. buffering length (secs)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="SettingsDialog.cpp" line="108"/>
+        <location filename="../src/SettingsDialog.cpp" line="125"/>
         <source>Enable track pre-buffering</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="SettingsDialog.cpp" line="109"/>
-        <location filename="SettingsDialog.cpp" line="132"/>
+        <location filename="../src/SettingsDialog.cpp" line="126"/>
+        <location filename="../src/SettingsDialog.cpp" line="150"/>
+        <source>UI Language</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/SettingsDialog.cpp" line="127"/>
+        <location filename="../src/SettingsDialog.cpp" line="151"/>
         <source>Display orientation</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="SettingsDialog.cpp" line="110"/>
-        <location filename="SettingsDialog.cpp" line="133"/>
+        <location filename="../src/SettingsDialog.cpp" line="128"/>
+        <location filename="../src/SettingsDialog.cpp" line="152"/>
         <source>Playlist options</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="SettingsDialog.cpp" line="111"/>
+        <location filename="../src/SettingsDialog.cpp" line="129"/>
         <source>Playlist load timeout (secs)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="SettingsDialog.cpp" line="112"/>
-        <location filename="SettingsDialog.cpp" line="135"/>
+        <location filename="../src/SettingsDialog.cpp" line="130"/>
+        <location filename="../src/SettingsDialog.cpp" line="154"/>
         <source>Pause on headset unplugged</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="SettingsDialog.cpp" line="113"/>
-        <location filename="SettingsDialog.cpp" line="136"/>
+        <location filename="../src/SettingsDialog.cpp" line="131"/>
+        <location filename="../src/SettingsDialog.cpp" line="155"/>
         <source>Scrobbling options</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="SettingsDialog.cpp" line="114"/>
+        <location filename="../src/SettingsDialog.cpp" line="132"/>
         <source>Enable scrobbling to Last.fm</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="SettingsDialog.cpp" line="115"/>
-        <location filename="SettingsDialog.cpp" line="138"/>
+        <location filename="../src/SettingsDialog.cpp" line="133"/>
+        <location filename="../src/SettingsDialog.cpp" line="157"/>
         <source>Last.fm username</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="SettingsDialog.cpp" line="116"/>
-        <location filename="SettingsDialog.cpp" line="139"/>
+        <location filename="../src/SettingsDialog.cpp" line="134"/>
+        <location filename="../src/SettingsDialog.cpp" line="158"/>
         <source>Last.fm password</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="SettingsDialog.cpp" line="117"/>
-        <location filename="SettingsDialog.cpp" line="140"/>
+        <location filename="../src/SettingsDialog.cpp" line="135"/>
+        <location filename="../src/SettingsDialog.cpp" line="159"/>
         <source>Save</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="SettingsDialog.cpp" line="125"/>
+        <location filename="../src/SettingsDialog.cpp" line="143"/>
         <source>Max. tracks</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="SettingsDialog.cpp" line="126"/>
+        <location filename="../src/SettingsDialog.cpp" line="144"/>
         <source>Max. albums</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="SettingsDialog.cpp" line="127"/>
+        <location filename="../src/SettingsDialog.cpp" line="145"/>
         <source>Max. artists</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="SettingsDialog.cpp" line="130"/>
+        <location filename="../src/SettingsDialog.cpp" line="148"/>
         <source>Min.buff.length (secs)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="SettingsDialog.cpp" line="131"/>
+        <location filename="../src/SettingsDialog.cpp" line="149"/>
         <source>Enable track pre-buff.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="SettingsDialog.cpp" line="134"/>
+        <location filename="../src/SettingsDialog.cpp" line="153"/>
         <source>Playlist load TO (secs)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="SettingsDialog.cpp" line="137"/>
+        <location filename="../src/SettingsDialog.cpp" line="156"/>
         <source>Enable Last.fm scrobbling</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../src/SettingsDialog.cpp" line="275"/>
+        <source>Please restart QSpot for language change to take effect!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Spotify::Album</name>
     <message>
-        <location filename="qspotify_src/album.cpp" line="91"/>
+        <location filename="../src/qspotify_src/album.cpp" line="91"/>
         <source>Album</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="qspotify_src/album.cpp" line="93"/>
+        <location filename="../src/qspotify_src/album.cpp" line="93"/>
         <source>Single</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="qspotify_src/album.cpp" line="95"/>
+        <location filename="../src/qspotify_src/album.cpp" line="95"/>
         <source>Compilation</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="qspotify_src/album.cpp" line="97"/>
-        <location filename="qspotify_src/album.cpp" line="110"/>
+        <location filename="../src/qspotify_src/album.cpp" line="97"/>
+        <location filename="../src/qspotify_src/album.cpp" line="110"/>
         <source>Appears on</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="qspotify_src/album.cpp" line="104"/>
+        <location filename="../src/qspotify_src/album.cpp" line="104"/>
         <source>Albums</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="qspotify_src/album.cpp" line="106"/>
+        <location filename="../src/qspotify_src/album.cpp" line="106"/>
         <source>Singles</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="qspotify_src/album.cpp" line="108"/>
+        <location filename="../src/qspotify_src/album.cpp" line="108"/>
         <source>Compilations</source>
         <translation type="unfinished"></translation>
     </message>
@@ -461,100 +480,100 @@ Special thanks to Markus (markusm@tmo) for assistance with the graphical design
 <context>
     <name>TrackView</name>
     <message>
-        <location filename="TrackView.cpp" line="54"/>
+        <location filename="../src/TrackView.cpp" line="54"/>
         <source>Play Album</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="TrackView.cpp" line="57"/>
+        <location filename="../src/TrackView.cpp" line="57"/>
         <source>Browse Album</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="TrackView.cpp" line="60"/>
+        <location filename="../src/TrackView.cpp" line="60"/>
         <source>Browse Artist</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="TrackView.cpp" line="71"/>
+        <location filename="../src/TrackView.cpp" line="71"/>
         <source>Sort tracks by</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="TrackView.cpp" line="73"/>
+        <location filename="../src/TrackView.cpp" line="73"/>
         <source>Playlist order</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="TrackView.cpp" line="73"/>
-        <location filename="TrackView.cpp" line="76"/>
+        <location filename="../src/TrackView.cpp" line="73"/>
+        <location filename="../src/TrackView.cpp" line="76"/>
         <source>Most popular</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="TrackView.cpp" line="73"/>
-        <location filename="TrackView.cpp" line="76"/>
+        <location filename="../src/TrackView.cpp" line="73"/>
+        <location filename="../src/TrackView.cpp" line="76"/>
         <source>Track name (ascending)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="TrackView.cpp" line="73"/>
-        <location filename="TrackView.cpp" line="76"/>
+        <location filename="../src/TrackView.cpp" line="73"/>
+        <location filename="../src/TrackView.cpp" line="76"/>
         <source>Track name (descending)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="TrackView.cpp" line="73"/>
-        <location filename="TrackView.cpp" line="76"/>
+        <location filename="../src/TrackView.cpp" line="73"/>
+        <location filename="../src/TrackView.cpp" line="76"/>
         <source>Artist name (ascending)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="TrackView.cpp" line="74"/>
-        <location filename="TrackView.cpp" line="77"/>
+        <location filename="../src/TrackView.cpp" line="74"/>
+        <location filename="../src/TrackView.cpp" line="77"/>
         <source>Artist name (descending)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="TrackView.cpp" line="74"/>
-        <location filename="TrackView.cpp" line="77"/>
+        <location filename="../src/TrackView.cpp" line="74"/>
+        <location filename="../src/TrackView.cpp" line="77"/>
         <source>Album name (ascending)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="TrackView.cpp" line="74"/>
-        <location filename="TrackView.cpp" line="77"/>
+        <location filename="../src/TrackView.cpp" line="74"/>
+        <location filename="../src/TrackView.cpp" line="77"/>
         <source>Album name (descending)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="TrackView.cpp" line="76"/>
+        <location filename="../src/TrackView.cpp" line="76"/>
         <source>Artist, album, track (ascending)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="TrackView.cpp" line="81"/>
-        <location filename="TrackView.cpp" line="190"/>
+        <location filename="../src/TrackView.cpp" line="81"/>
+        <location filename="../src/TrackView.cpp" line="190"/>
         <source>FM Transmitter</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="TrackView.cpp" line="119"/>
+        <location filename="../src/TrackView.cpp" line="119"/>
         <source>Loading album tracks</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="TrackView.cpp" line="155"/>
+        <location filename="../src/TrackView.cpp" line="155"/>
         <source>Fetching of album tracks failed: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="TrackView.cpp" line="161"/>
+        <location filename="../src/TrackView.cpp" line="161"/>
         <source>Failed to load tracks!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="TrackView.cpp" line="273"/>
+        <location filename="../src/TrackView.cpp" line="273"/>
         <source>Search results: </source>
         <translation type="unfinished"></translation>
     </message>
